#include <sys/types.h>
#include <unistd.h>
#include <errno.h>
#include <signal.h>
#include "common.h"

int spawn_child(char **args, int in, int out, int err, int *close_fds) {
	int pid = fork();
	if (pid < 0)
		dies("fork failed");

	if (pid == 0) {
		if (setsid() < 0)
			dies("setsid failed");

		if (in != -1)
			if (dup2(in, 0) < 0)
				dies("dup2 failed");
		if (out != -1)
			if (dup2(out, 1) < 0)
				dies("dup2 failed");
		if (err != -1)
			if (dup2(err, 2) < 0)
				dies("dup2 failed");

		if (close_fds != NULL) {
			while (*close_fds != -1)
				close(*close_fds++);
		}

		execvp(args[0], args);
		dies("execvp failed");
	}

	return pid;
}

void kill_child(int pid, int signal) {
	if (pid == 0 || pid == -1)
		return;

	if (kill(pid, signal) < 0 && errno != ESRCH)
		dies("unable to send signal to child");
}

